@@ -35,7 +35,7 @@ class Redis_Cluster_Test extends Redis_Test {
 
     /* Load our seeds on construction */
     public function __construct() {
-        $str_nodemap_file = dirname($_SERVER['PHP_SELF']) . '/nodes/nodemap';
+        $str_nodemap_file = dirname(dirname($_SERVER['PHP_SELF'])) . '/nodes/nodemap';
 
         if (!file_exists($str_nodemap_file)) {
             fprintf(STDERR, "Error:  Can't find nodemap file for seeds!\n");
@@ -73,13 +73,6 @@ class Redis_Cluster_Test extends Redis_Test {
     }
 
     public function testRandomKey() {
-        /* Ensure some keys are present to test */
-        for ($i = 0; $i < 1000; $i++) {
-            if (rand(1, 2) == 1) {
-                $this->redis->set("key:$i", "val:$i");
-            }
-        }
-
         for ($i = 0; $i < 1000; $i++) {
             $k = $this->redis->randomKey("key:$i");
             $this->assertTrue($this->redis->exists($k));
